using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

namespace KidzPad_SDG
{
	/// <summary>
	/// Summary description for ButtonControl.
	/// </summary>
	public class ButtonControl : Sdgt.SdgUserControl
	{
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		public bool pressed;
		private String Caption = "Clear Screen";

		public ButtonControl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			pressed = false;

		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// ButtonControl
			// 
			this.Name = "ButtonControl";
			this.Size = new System.Drawing.Size(150, 64);
			this.Paint += new System.Windows.Forms.PaintEventHandler(this.ButtonControl_Paint);

		}
		#endregion

		private void ButtonControl_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{
			drawControl();
		}

		// Draw the button
		private void drawControl ()
		{
			// Depending on whether any mice are pressing the button, draw the appropriate button graphic. 
			if (!pressed)
			{
				drawUnpressedButton ();
			} 
			else 
			{ 
				drawPressedButton ();
			}
		}

		// Draw the Button Graphics showing its 'unpressed' state
		private void drawUnpressedButton ()
		{
			Graphics gfx = this.CreateGraphics();
			Pen p;
			gfx.Clear (this.BackColor);
			

			Point ptl = new Point (0, 0);
			Point ptr = new Point (this.Width - 1, 0);
			Point pbl = new Point (0, this.Height - 1);
			Point pbr = new Point (this.Width - 1, this.Height - 1);
			
			//White lines on inside left side and top
			p = new Pen (SystemBrushes.ControlLightLight, 4);
			gfx.DrawLine (p, ptl, ptr);
			gfx.DrawLine (p, ptl, pbl);
			
			//Grey lines on inside right side and bottom
			p = new Pen (SystemBrushes.ControlDark, 3);
			gfx.DrawLine (p, pbl, pbr);
			gfx.DrawLine (p, pbr, ptr);

			//Dark lines surround entire button
			p = new Pen (SystemBrushes.ControlDarkDark, 1);
			gfx.DrawLine (p, ptl, ptr);
			gfx.DrawLine (p, ptl, pbl);
			gfx.DrawLine (p, pbl, pbr);
			gfx.DrawLine (p, pbr, ptr);

			drawCenteredCaption ( new Point ( (this.Width - 1) / 2, (this.Height - 1) / 2));
		}

		// Draw the Button Graphics showing its 'pressed' state
		private void drawPressedButton ()
		{
			Graphics gfx = this.CreateGraphics();
			Pen p;
			gfx.Clear (this.BackColor);
			

			Point ptl = new Point (0, 0);
			Point ptr = new Point (this.Width - 1, 0);
			Point pbl = new Point (0, this.Height - 1);
			Point pbr = new Point (this.Width - 1, this.Height - 1);
			
			//Dark lines on inside left side and top
			p = new Pen (SystemBrushes.ControlDarkDark, 4);
			gfx.DrawLine (p, ptl, ptr);
			gfx.DrawLine (p, ptl, pbl);
			
			//Dark lines surround entire button
			p = new Pen (SystemBrushes.ControlDarkDark, 1);
			gfx.DrawLine (p, ptl, ptr);
			gfx.DrawLine (p, ptl, pbl);
			gfx.DrawLine (p, pbl, pbr);
			gfx.DrawLine (p, pbr, ptr);

			// Shift the Caption over a bit to give it that 3d click feel
			drawCenteredCaption ( new Point ( (this.Width + 2)/2, (this.Height + 2)/2) );
		}

		// Drawing the Caption in the Button
		private void drawCenteredCaption (Point centerpt)
		{
			Graphics gfx = this.CreateGraphics();

			//Set the string format alignment to be centered 
			StringFormat strfmt = new StringFormat();
			strfmt.Alignment = StringAlignment.Center;
			strfmt.LineAlignment = StringAlignment.Center;
			
			// if the button is enabled, draw the font normally. Otherwise, draw it in a light color and embossed in white
			if (this.Enabled) 
			{
				Brush b = new SolidBrush (this.ForeColor); 
				gfx.DrawString (this.Caption, this.Font, b, centerpt, strfmt); 
			} 
			else 
			{
				gfx.DrawString (this.Caption, this.Font, Brushes.White, centerpt.X - 1, centerpt.Y - 1, strfmt); 
				gfx.DrawString (this.Caption, this.Font, Brushes.White, centerpt.X + 1, centerpt.Y + 1, strfmt); 
				gfx.DrawString (this.Caption, this.Font, SystemBrushes.ControlDark, centerpt, strfmt); 
			}
		}
	}
}
